==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/CircleCR/ts/CircleCR_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CircleCR</name>
    <message>
        <source>Center or radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Center lub promień</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <location filename="../CircleCR.ui" line="+17"/>
        <location filename="../CircleCRDialog.ui" line="+89"/>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation type="unfinished">Promień:</translation>
    </message>
    <message>
        <location line="+33"/>
        <location filename="../CircleCRDialog.ui" line="-60"/>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CircleCRInit.js" line="+2"/>
        <source>Center, &amp;Radius</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Środek, &amp;promień</translatorcomment>
        <translation type="unfinished">Środek, &amp;promień</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle from center and radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj koło od środka i promienia</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/CircleCR/ts/CircleCR_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleCR</name>
    <message>
        <source>Center or radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Center lub promień</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <location filename="../CircleCR.ui" line="+17"/>
        <location filename="../CircleCRDialog.ui" line="+89"/>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation>Promień:</translation>
    </message>
    <message>
        <location line="+33"/>
        <location filename="../CircleCRDialog.ui" line="-60"/>
        <source>Angle:</source>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>Punkt odniesienia:</translation>
    </message>
    <message>
        <location filename="../CircleCRInit.js" line="+2"/>
        <source>Center, &amp;Radius</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Środek, &amp;promień</translatorcomment>
        <translation>Środek, p&amp;romień</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle from center and radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje okrąg od środka i danym promieniu</translation>
    </message>
</context>
</TS>
